# -*- coding: utf-8 -*-

""" Coworker module """

from odoo import models, fields, api, _
from odoo.exceptions import ValidationError

class Coworker(models.Model):
    """ Coworker model """
    _name = 'coworking.coworker'
    _description = 'Coworker model definition'
    _order = 'id desc'

    name = fields.Char(required=True)
    firstname = fields.Char('First name', required=True)
    coworker_type = fields.Selection([('staffer', 'Staffer'),
                                      ('worker', 'Worker'), ('member', 'Member'),
                                      ('volunteer', 'Volunteer'),
                                      ('visitor', 'Visitor')])
    company_name = fields.Char('Company')
    job = fields.Char()
    contact_date = fields.Date(default=fields.Date.context_today)
    street = fields.Char()
    contact_zip = fields.Char()
    city = fields.Char()
    phone_number = fields.Char()
    gsm = fields.Char('GSM')
    email = fields.Char()
    url = fields.Char('URL')
    note = fields.Text()

    is_done = fields.Boolean('Done?')
    is_active = fields.Boolean('Active?', default=True)


    @api.constrains('contact_date')
    def _check_contact_date(self):
        if self.contact_date > fields.Date.context_today(self):
            raise ValidationError(_('Date most be egual of inferior to to day'))
